@@ -15,7 +15,6 @@
 #include "KWayland/Client/plasmawindowmanagement.h"
 #include "../../src/server/display.h"
 #include "../../src/server/compositor_interface.h"
-#include "../../src/server/region_interface.h"
 #include "../../src/server/plasmawindowmanagement_interface.h"
 #include "../../src/server/surface_interface.h"
 #include <wayland-plasma-window-management-client-protocol.h>
@@ -101,7 +100,7 @@ void TestWindowManagement::init()
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
-    QSignalSpy connectedSpy(m_connection, SIGNAL(connected()));
+    QSignalSpy connectedSpy(m_connection, &KWayland::Client::ConnectionThread::connected);
     m_connection->setSocketName(s_socketName);
 
     m_thread = new QThread(this);
@@ -117,10 +116,10 @@ void TestWindowManagement::init()
     QVERIFY(m_queue->isValid());
 
     m_registry = new KWayland::Client::Registry(this);
-    QSignalSpy compositorSpy(m_registry, SIGNAL(compositorAnnounced(quint32,quint32)));
+    QSignalSpy compositorSpy(m_registry, &KWayland::Client::Registry::compositorAnnounced);
     QVERIFY(compositorSpy.isValid());
 
-    QSignalSpy windowManagementSpy(m_registry, SIGNAL(plasmaWindowManagementAnnounced(quint32,quint32)));
+    QSignalSpy windowManagementSpy(m_registry, &KWayland::Client::Registry::plasmaWindowManagementAnnounced);
     QVERIFY(windowManagementSpy.isValid());
 
 
@@ -141,7 +140,7 @@ void TestWindowManagement::init()
     QVERIFY(windowManagementSpy.wait());
     m_windowManagement = m_registry->createPlasmaWindowManagement(windowManagementSpy.first().first().value<quint32>(), windowManagementSpy.first().last().value<quint32>(), this);
 
-    QSignalSpy windowSpy(m_windowManagement, SIGNAL(windowCreated(KWayland::Client::PlasmaWindow*)));
+    QSignalSpy windowSpy(m_windowManagement, &KWayland::Client::PlasmaWindowManagement::windowCreated);
     QVERIFY(windowSpy.isValid());
     m_windowInterface = m_windowManagementInterface->createWindow(this, QUuid::createUuid());
     m_windowInterface->setPid(1337);
@@ -149,7 +148,7 @@ void TestWindowManagement::init()
     QVERIFY(windowSpy.wait());
     m_window = windowSpy.first().first().value<KWayland::Client::PlasmaWindow *>();
 
-    QSignalSpy serverSurfaceCreated(m_compositorInterface, SIGNAL(surfaceCreated(KWaylandServer::SurfaceInterface*)));
+    QSignalSpy serverSurfaceCreated(m_compositorInterface, &KWaylandServer::CompositorInterface::surfaceCreated);
     QVERIFY(serverSurfaceCreated.isValid());
 
     m_surface = m_compositor->createSurface(this);
@@ -164,7 +163,7 @@ void TestWindowManagement::testWindowTitle()
 {
     m_windowInterface->setTitle(QStringLiteral("Test Title"));
 
-    QSignalSpy titleSpy(m_window, SIGNAL(titleChanged()));
+    QSignalSpy titleSpy(m_window, &KWayland::Client::PlasmaWindow::titleChanged);
     QVERIFY(titleSpy.isValid());
 
     QVERIFY(titleSpy.wait());
@@ -176,7 +175,7 @@ void TestWindowManagement::testMinimizedGeometry()
 {
     m_window->setMinimizedGeometry(m_surface, QRect(5, 10, 100, 200));
 
-    QSignalSpy geometrySpy(m_windowInterface, SIGNAL(minimizedGeometriesChanged()));
+    QSignalSpy geometrySpy(m_windowInterface, &KWaylandServer::PlasmaWindowInterface::minimizedGeometriesChanged);
     QVERIFY(geometrySpy.isValid());
 
     QVERIFY(geometrySpy.wait());
@@ -241,15 +240,12 @@ void TestWindowManagement::testUseAfterUnmap()
     QVERIFY(unmappedSpy.isValid());
     QSignalSpy destroyedSpy(m_window, &QObject::destroyed);
     QVERIFY(destroyedSpy.isValid());
-    m_windowInterface->unmap();
+    m_windowInterface->deleteLater();
+    m_windowInterface = nullptr;
     m_window->requestClose();
     QVERIFY(unmappedSpy.wait());
     QVERIFY(destroyedSpy.wait());
     m_window = nullptr;
-    QSignalSpy serverDestroyedSpy(m_windowInterface, &QObject::destroyed);
-    QVERIFY(serverDestroyedSpy.isValid());
-    QVERIFY(serverDestroyedSpy.wait());
-    m_windowInterface = nullptr;
 }
 
 void TestWindowManagement::testServerDelete()
@@ -283,14 +279,11 @@ void TestWindowManagement::testActiveWindowOnUnmapped()
     QVERIFY(destroyedSpy.isValid());
     QSignalSpy serverDestroyedSpy(m_windowInterface, &QObject::destroyed);
     QVERIFY(serverDestroyedSpy.isValid());
-    m_windowManagementInterface->unmapWindow(m_windowInterface);
+    delete m_windowInterface;
+    m_windowInterface = nullptr;
     QVERIFY(activeWindowChangedSpy.wait());
     QVERIFY(!m_windowManagement->activeWindow());
-    QVERIFY(destroyedSpy.wait());
-    QCOMPARE(destroyedSpy.count(), 1);
-    m_window = nullptr;
-    QVERIFY(serverDestroyedSpy.wait());
-    m_windowInterface = nullptr;
+
 }
 
 void TestWindowManagement::testDeleteActiveWindow()
@@ -318,14 +311,16 @@ void TestWindowManagement::testCreateAfterUnmap()
 {
     // this test verifies that we don't get a protocol error on client side when creating an already unmapped window.
     QCOMPARE(m_windowManagement->children().count(), 1);
+
+    QSignalSpy windowAddedSpy(m_windowManagement, &KWayland::Client::PlasmaWindowManagement::windowCreated);
+
     // create and unmap in one go
     // client will first handle the create, the unmap will be sent once the server side is bound
-    auto serverWindow = m_windowManagementInterface->createWindow(this, QUuid::createUuid());
-    serverWindow->unmap();
+    auto serverWindow = m_windowManagementInterface->createWindow(m_windowManagementInterface, QUuid::createUuid());
+    delete serverWindow;
     QCOMPARE(m_windowManagementInterface->children().count(), 0);
-    QCoreApplication::instance()->processEvents();
-    QCoreApplication::instance()->processEvents(QEventLoop::WaitForMoreEvents);
-    QTRY_COMPARE(m_windowManagement->children().count(), 2);
+
+    windowAddedSpy.wait();
     auto window = dynamic_cast<KWayland::Client::PlasmaWindow*>(m_windowManagement->children().last());
     QVERIFY(window);
     // now this is not yet on the server, on the server it will be after next roundtrip
@@ -334,15 +329,8 @@ void TestWindowManagement::testCreateAfterUnmap()
     QSignalSpy clientDestroyedSpy(window, &QObject::destroyed);
     QVERIFY(clientDestroyedSpy.isValid());
     QVERIFY(clientDestroyedSpy.wait());
+    // Verify that any wrappers created for our temporary window are now gone
     QCOMPARE(m_windowManagement->children().count(), 1);
-    // the server side created a helper PlasmaWindowInterface with PlasmaWindowManagementInterface as parent
-    // it emitted unmapped so we can be sure it will be destroyed directly
-    QCOMPARE(m_windowManagementInterface->children().count(), 1);
-    auto helperWindow = qobject_cast<KWaylandServer::PlasmaWindowInterface*>(m_windowManagementInterface->children().first());
-    QVERIFY(helperWindow);
-    QSignalSpy helperDestroyedSpy(helperWindow, &QObject::destroyed);
-    QVERIFY(helperDestroyedSpy.isValid());
-    QVERIFY(helperDestroyedSpy.wait());
 }
 
 void TestWindowManagement::testRequests_data()
@@ -515,7 +503,7 @@ void TestWindowManagement::testParentWindow()
     // now let's create a second window
     QSignalSpy windowAddedSpy(m_windowManagement, &PlasmaWindowManagement::windowCreated);
     QVERIFY(windowAddedSpy.isValid());
-    auto serverTransient = m_windowManagementInterface->createWindow(this, QUuid::createUuid());
+    QScopedPointer<KWaylandServer::PlasmaWindowInterface> serverTransient(m_windowManagementInterface->createWindow(this, QUuid::createUuid()));
     serverTransient->setParentWindow(m_windowInterface);
     QVERIFY(windowAddedSpy.wait());
     auto transient = windowAddedSpy.first().first().value<PlasmaWindow*>();
@@ -534,7 +522,7 @@ void TestWindowManagement::testParentWindow()
     QCOMPARE(transient->parentWindow().data(), parentWindow);
 
     // now let's try to unmap the parent
-    m_windowInterface->unmap();
+    m_windowInterface->deleteLater();
     m_window = nullptr;
     m_windowInterface = nullptr;
     QVERIFY(parentWindowChangedSpy.wait());
@@ -578,41 +566,28 @@ void TestWindowManagement::testIcon()
 {
     using namespace KWayland::Client;
 
-    // initially, the server should send us an icon
+    // initially, there shouldn't be any icon
     QSignalSpy iconChangedSpy(m_window, &PlasmaWindow::iconChanged);
     QVERIFY(iconChangedSpy.isValid());
+    QVERIFY(m_window->icon().isNull());
+
+    // create an icon with a pixmap
+    QImage p(32, 32, QImage::Format_ARGB32_Premultiplied);
+    p.fill(Qt::red);
+    const QIcon dummyIcon(QPixmap::fromImage(p));
+    m_windowInterface->setIcon(dummyIcon);
     QVERIFY(iconChangedSpy.wait());
     QCOMPARE(iconChangedSpy.count(), 1);
-    if (!QIcon::hasThemeIcon(QStringLiteral("wayland"))) {
-        QEXPECT_FAIL("", "no icon", Continue);
-    }
-    QCOMPARE(m_window->icon().name(), QStringLiteral("wayland"));
+    QCOMPARE(m_window->icon().pixmap(32, 32), dummyIcon.pixmap(32, 32));
 
-    // first goes from themed name to empty
-    m_windowInterface->setIcon(QIcon());
+    // let's set a themed icon
+    m_windowInterface->setIcon(QIcon::fromTheme(QStringLiteral("wayland")));
     QVERIFY(iconChangedSpy.wait());
     QCOMPARE(iconChangedSpy.count(), 2);
     if (!QIcon::hasThemeIcon(QStringLiteral("wayland"))) {
-        QEXPECT_FAIL("", "no icon", Continue);
+        QEXPECT_FAIL("", "no wayland icon", Continue);
     }
     QCOMPARE(m_window->icon().name(), QStringLiteral("wayland"));
-
-    // create an icon with a pixmap
-    QPixmap p(32, 32);
-    p.fill(Qt::red);
-    m_windowInterface->setIcon(p);
-    QVERIFY(iconChangedSpy.wait());
-    QCOMPARE(iconChangedSpy.count(), 3);
-    QCOMPARE(m_window->icon().pixmap(32, 32), p);
-
-    // let's set a themed icon
-    m_windowInterface->setIcon(QIcon::fromTheme(QStringLiteral("xorg")));
-    QVERIFY(iconChangedSpy.wait());
-    QCOMPARE(iconChangedSpy.count(), 4);
-    if (!QIcon::hasThemeIcon(QStringLiteral("xorg"))) {
-        QEXPECT_FAIL("", "no icon", Continue);
-    }
-    QCOMPARE(m_window->icon().name(), QStringLiteral("xorg"));
 }
 
 void TestWindowManagement::testPid()
@@ -623,13 +598,11 @@ void TestWindowManagement::testPid()
 
     //test server not setting a PID for whatever reason
     QScopedPointer<KWaylandServer::PlasmaWindowInterface> newWindowInterface(m_windowManagementInterface->createWindow(this, QUuid::createUuid()));
-    QSignalSpy windowSpy(m_windowManagement, SIGNAL(windowCreated(KWayland::Client::PlasmaWindow*)));
+    QSignalSpy windowSpy(m_windowManagement, &KWayland::Client::PlasmaWindowManagement::windowCreated);
     QVERIFY(windowSpy.wait());
     QScopedPointer<PlasmaWindow> newWindow( windowSpy.first().first().value<KWayland::Client::PlasmaWindow *>());
     QVERIFY(newWindow);
     QVERIFY(newWindow->pid() == 0);
-
-
 }
 
 void TestWindowManagement::testApplicationMenu()
