@@ -3,8 +3,7 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef KWAYLAND_SERVER_IDLEINHIBIT_INTERFACE_H
-#define KWAYLAND_SERVER_IDLEINHIBIT_INTERFACE_H
+#pragma once
 
 #include <QObject>
 
@@ -22,9 +21,7 @@ class IdleInhibitManagerV1InterfacePrivate;
  * The IdleInhibitorManagerInterface is used by clients to inhibit idle on a
  * SurfaceInterface. Whether a SurfaceInterface inhibits idle is exposes through
  * @link{SurfaceInterface::inhibitsIdle}.
- *
- * @since 5.41
- **/
+ */
 class KWAYLANDSERVER_EXPORT IdleInhibitManagerV1Interface : public QObject
 {
     Q_OBJECT
@@ -38,5 +35,3 @@ private:
 };
 
 }
-
-#endif
