@@ -3,8 +3,7 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef WAYLAND_SERVER_PRIMARY_SELECTION_OFFER_INTERFACE_H
-#define WAYLAND_SERVER_PRIMARY_SELECTION_OFFER_INTERFACE_H
+#pragma once
 
 #include <QObject>
 
@@ -24,7 +23,7 @@ class PrimarySelectionOfferV1InterfacePrivate;
 /**
  * @brief Represents the Resource for the wl_data_offer interface.
  * Lifespan is mapped to the underlying object
- **/
+ */
 class KWAYLANDSERVER_EXPORT PrimarySelectionOfferV1Interface : public QObject
 {
     Q_OBJECT
@@ -44,5 +43,3 @@ private:
 }
 
 Q_DECLARE_METATYPE(KWaylandServer::PrimarySelectionOfferV1Interface*)
-
-#endif
