@@ -1,32 +1,33 @@
 /*
     SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
+    SPDX-FileCopyrightText: 2021 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef WAYLAND_SERVER_SEAT_INTERFACE_H
-#define WAYLAND_SERVER_SEAT_INTERFACE_H
+#pragma once
+
+#include <KWaylandServer/kwaylandserver_export.h>
 
 #include <QObject>
 #include <QPoint>
 #include <QMatrix4x4>
 
-#include <KWaylandServer/kwaylandserver_export.h>
-#include "global.h"
-#include "keyboard_interface.h"
-#include "pointer_interface.h"
-#include "touch_interface.h"
-
 struct wl_client;
 struct wl_resource;
 
 namespace KWaylandServer
 {
 
-class DataDeviceInterface;
 class AbstractDataSource;
+class DataDeviceInterface;
 class Display;
+class KeyboardInterface;
+class PointerInterface;
+class SeatInterfacePrivate;
 class SurfaceInterface;
-class TextInputInterface;
+class TextInputV2Interface;
+class TextInputV3Interface;
+class TouchInterface;
 
 /**
  * Describes the source types for axis events. This indicates to the
@@ -45,15 +46,31 @@ class TextInputInterface;
  * The "wheel tilt" axis source indicates that the actual device is a
  * wheel but the scroll event is not caused by a rotation but a
  * (usually sideways) tilt of the wheel.
- *
- * @since 5.59
- **/
+ */
 enum class PointerAxisSource {
     Unknown,
     Wheel,
     Finger,
     Continuous,
-    WheelTilt
+    WheelTilt,
+};
+
+/**
+ * This enum type is used to describe the state of a pointer button. It
+ * is equivalent to the @c wl_pointer.button_state enum.
+ */
+enum class PointerButtonState : quint32 {
+    Released = 0,
+    Pressed = 1,
+};
+
+/**
+ * This enum type is used to describe the state of a keyboard key. It is
+ * equivalent to the @c wl_keyboard.key_state enum.
+ */
+enum class KeyboardKeyState : quint32 {
+    Released = 0,
+    Pressed = 1,
 };
 
 /**
@@ -88,53 +105,58 @@ enum class PointerAxisSource {
  * // example for pointer
  * seat->setFocusedPointerSurface(surface, QPointF(100, 200)); // surface at it's global position
  * seat->setTimestamp(100);
- * seat->setPointerPos(QPointF(350, 210)); // global pos, local pos in surface: 250,10
+ * seat->notifyPointerMotion(QPointF(350, 210)); // global pos, local pos in surface: 250,10
+ * seat->notifyPointerFrame();
  * seat->setTimestamp(110);
- * seat->pointerButtonPressed(Qt::LeftButton);
+ * seat->notifyPointerButton(Qt::LeftButton, PointerButtonState::Pressed);
+ * seat->notifyPointerFrame();
  * seat->setTimestamp(120);
- * seat->pointerButtonReleased(Qt::LeftButton);
+ * seat->notifyPointerButton(Qt::LeftButton, PointerButtonState::Released);
+ * seat->notifyPointerFrame();
  * @endcode
  *
  * @see KeyboardInterface
  * @see PointerInterface
  * @see TouchInterface
  * @see SurfaceInterface
- **/
-class KWAYLANDSERVER_EXPORT SeatInterface : public Global
+ */
+class KWAYLANDSERVER_EXPORT SeatInterface : public QObject
 {
     Q_OBJECT
     /**
      * The name of the Seat
-     **/
+     */
     Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)
     /**
      * Whether the SeatInterface supports a pointer device.
-     **/
+     */
     Q_PROPERTY(bool pointer READ hasPointer WRITE setHasPointer NOTIFY hasPointerChanged)
     /**
      * Whether the SeatInterface supports a keyboard device.
-     **/
+     */
     Q_PROPERTY(bool keyboard READ hasKeyboard WRITE setHasKeyboard NOTIFY hasKeyboardChanged)
     /**
      * Whether the SeatInterface supports a touch device.
      * @deprecated Since 5.5, use touch
-     **/
+     */
     Q_PROPERTY(bool tourch READ hasTouch WRITE setHasTouch NOTIFY hasTouchChanged)
     /**
      * Whether the SeatInterface supports a touch device.
-     **/
+     */
     Q_PROPERTY(bool touch READ hasTouch WRITE setHasTouch NOTIFY hasTouchChanged)
     /**
      * The global pointer position.
-     **/
-    Q_PROPERTY(QPointF pointerPos READ pointerPos WRITE setPointerPos NOTIFY pointerPosChanged)
+     */
+    Q_PROPERTY(QPointF pointerPos READ pointerPos WRITE notifyPointerMotion NOTIFY pointerPosChanged)
     /**
      * The current timestamp passed to the input events.
-     **/
+     */
     Q_PROPERTY(quint32 timestamp READ timestamp WRITE setTimestamp NOTIFY timestampChanged)
 public:
+    explicit SeatInterface(Display *display, QObject *parent = nullptr);
     virtual ~SeatInterface();
 
+    Display *display() const;
     QString name() const;
     bool hasPointer() const;
     bool hasKeyboard() const;
@@ -150,87 +172,73 @@ public:
 
     /**
      * @name Drag'n'Drop related methods
-     **/
+     */
     ///@{
     /**
      * @returns whether there is currently a drag'n'drop going on.
-     * @since 5.6
      * @see isDragPointer
      * @see isDragTouch
      * @see dragStarted
      * @see dragEnded
-     **/
+     */
     bool isDrag() const;
     /**
      * @returns whether the drag'n'drop is operated through the pointer device
-     * @since 5.6
      * @see isDrag
      * @see isDragTouch
-     **/
+     */
     bool isDragPointer() const;
     /**
      * @returns whether the drag'n'drop is operated through the touch device
-     * @since 5.6
      * @see isDrag
      * @see isDragPointer
-     **/
+     */
     bool isDragTouch() const;
     /**
      * @returns The transformation applied to go from global to local coordinates for drag motion events.
      * @see dragSurfaceTransformation
-     * @since 5.6
-     **/
+     */
     QMatrix4x4 dragSurfaceTransformation() const;
     /**
      * @returns The currently focused Surface for drag motion events.
-     * @since 5.6
      * @see dragSurfaceTransformation
      * @see dragSurfaceChanged
-     **/
+     */
     SurfaceInterface *dragSurface() const;
-    /**
-     * @returns The PointerInterface which triggered the drag operation
-     * @since 5.6
-     * @see isDragPointer
-     **/
-    PointerInterface *dragPointer() const;
     /**
      * @returns The DataDeviceInterface which started the drag and drop operation.
      * @see isDrag
-     * @since 5.6
-     **/
+     */
     DataDeviceInterface *dragSource() const;
     /**
      * Sets the current drag target to @p surface.
      *
      * Sends a drag leave event to the current target and an enter event to @p surface.
      * The enter position is derived from @p globalPosition and transformed by @p inputTransformation.
-     * @since 5.6
-     **/
+     */
     void setDragTarget(SurfaceInterface *surface, const QPointF &globalPosition, const QMatrix4x4 &inputTransformation);
     /**
      * Sets the current drag target to @p surface.
      *
      * Sends a drag leave event to the current target and an enter event to @p surface.
      * The enter position is derived from current global position and transformed by @p inputTransformation.
-     * @since 5.6
-     **/
+     */
     void setDragTarget(SurfaceInterface *surface, const QMatrix4x4 &inputTransformation = QMatrix4x4());
     ///@}
 
     /**
      * @name Pointer related methods
-     **/
+     */
     ///@{
     /**
      * Updates the global pointer @p pos.
      *
      * Sends a pointer motion event to the focused pointer surface.
-     **/
-    void setPointerPos(const QPointF &pos);
+     */
+    void notifyPointerMotion(const QPointF &pos);
     /**
      * @returns the global pointer position
-     **/
+     */
     QPointF pointerPos() const;
     /**
      * Sets the focused pointer @p surface.
@@ -257,7 +265,7 @@ public:
      * @see focusedPointerSurfacePosition
      * @see setFocusedPointerSurfaceTransformation
      * @see focusedPointerSurfaceTransformation
-     **/
+     */
     void setFocusedPointerSurface(SurfaceInterface *surface, const QPointF &surfacePosition = QPoint());
     /**
      * Sets the focused pointer @p surface.
@@ -281,19 +289,14 @@ public:
      * @see focusedPointerSurfacePosition
      * @see setFocusedPointerSurfaceTransformation
      * @see focusedPointerSurfaceTransformation
-     * @since 5.6
-     **/
+     */
     void setFocusedPointerSurface(SurfaceInterface *surface, const QMatrix4x4 &transformation);
     /**
      * @returns The currently focused pointer surface, that is the surface receiving pointer events.
      * @see setFocusedPointerSurface
-     **/
+     */
     SurfaceInterface *focusedPointerSurface() const;
-    /**
-     * @returns The PointerInterface belonging to the focused pointer surface, if any.
-     * @see setFocusedPointerSurface
-     **/
-    PointerInterface *focusedPointer() const;
+    PointerInterface *pointer() const;
     /**
      * Updates the global position of the currently focused pointer surface.
      *
@@ -307,14 +310,14 @@ public:
      * @see setFocusedPointerSurface
      * @see focusedPointerSurfaceTransformation
      * @see setFocusedPointerSurfaceTransformation
-     **/
+     */
     void setFocusedPointerSurfacePosition(const QPointF &surfacePosition);
     /**
      * @returns The position of the focused pointer surface in global coordinates.
      * @see setFocusedPointerSurfacePosition
      * @see setFocusedPointerSurface
      * @see focusedPointerSurfaceTransformation
-     **/
+     */
     QPointF focusedPointerSurfacePosition() const;
     /**
      * Sets the @p transformation for going from global to local coordinates.
@@ -325,54 +328,37 @@ public:
      * @see focusedPointerSurfaceTransformation
      * @see focusedPointerSurfacePosition
      * @see setFocusedPointerSurfacePosition
-     * @since 5.6
-     **/
+     */
     void setFocusedPointerSurfaceTransformation(const QMatrix4x4 &transformation);
     /**
      * @returns The transformation applied to pointer position to go from global to local coordinates.
      * @see setFocusedPointerSurfaceTransformation
-     * @since 5.6
-     **/
+     */
     QMatrix4x4 focusedPointerSurfaceTransformation() const;
     /**
-     * Marks the @p button as pressed.
-     *
-     * If there is a focused pointer surface a button pressed event is sent to it.
-     *
-     * @param button The Linux button code
-     **/
-    void pointerButtonPressed(quint32 button);
+     * Marks the specified @a button as pressed or released based on @a state.
+     */
+    void notifyPointerButton(quint32 button, PointerButtonState state);
     /**
      * @overload
-     **/
-    void pointerButtonPressed(Qt::MouseButton button);
-    /**
-     * Marks the @p button as released.
-     *
-     * If there is a focused pointer surface a button release event is sent to it.
-     *
-     * @param button The Linux button code
-     **/
-    void pointerButtonReleased(quint32 button);
-    /**
-     * @overload
-     **/
-    void pointerButtonReleased(Qt::MouseButton button);
+     */
+    void notifyPointerButton(Qt::MouseButton button, PointerButtonState state);
+    void notifyPointerFrame();
     /**
      * @returns whether the @p button is pressed
-     **/
+     */
     bool isPointerButtonPressed(quint32 button) const;
     /**
      * @returns whether the @p button is pressed
-     **/
+     */
     bool isPointerButtonPressed(Qt::MouseButton button) const;
     /**
      * @returns the last serial for @p button.
-     **/
+     */
     quint32 pointerButtonSerial(quint32 button) const;
     /**
      * @returns the last serial for @p button.
-     **/
+     */
     quint32 pointerButtonSerial(Qt::MouseButton button) const;
     /**
      * Sends axis events to the currently focused pointer surface.
@@ -381,18 +367,11 @@ public:
      * @param delta The length of a vector along the specified axis @p orientation.
      * @param discreteDelta The number of discrete steps, e.g. mouse wheel clicks.
      * @param source Describes how the axis event was physically generated.
-     * @since 5.59
-     * @todo Drop V5 suffix with KF6.
-     **/
-    void pointerAxisV5(Qt::Orientation orientation, qreal delta, qint32 discreteDelta, PointerAxisSource source);
-    /**
-     * @see pointerAxisV5
-     **/
-    void pointerAxis(Qt::Orientation orientation, quint32 delta);
+     */
+    void notifyPointerAxis(Qt::Orientation orientation, qreal delta, qint32 discreteDelta, PointerAxisSource source);
     /**
      * @returns true if there is a pressed button with the given @p serial
-     * @since 5.6
-     **/
+     */
     bool hasImplicitPointerGrab(quint32 serial) const;
 
     /**
@@ -427,8 +406,7 @@ public:
      * @param deltaNonAccelerated non-accelerated motion vector
      * @param microseconds timestamp with microseconds granularity
      * @see setPointerPos
-     * @since 5.28
-     **/
+     */
     void relativePointerMotion(const QSizeF &delta, const QSizeF &deltaNonAccelerated, quint64 microseconds);
 
     /**
@@ -451,8 +429,7 @@ public:
      * @see endPointerSwipeGesture
      * @see cancelPointerSwipeGesture
      * @see startPointerPinchGesture
-     * @since 5.29
-     **/
+     */
     void startPointerSwipeGesture(quint32 fingerCount);
 
     /**
@@ -462,8 +439,7 @@ public:
      * @see startPointerSwipeGesture
      * @see endPointerSwipeGesture
      * @see cancelPointerSwipeGesture
-     * @since 5.29
-     **/
+     */
     void updatePointerSwipeGesture(const QSizeF &delta);
 
     /**
@@ -472,7 +448,7 @@ public:
      * @see updatePointerSwipeGesture
      * @see cancelPointerSwipeGesture
      * @see 5.29
-     **/
+     */
     void endPointerSwipeGesture();
 
     /**
@@ -480,8 +456,7 @@ public:
      * @see startPointerSwipeGesture
      * @see updatePointerSwipeGesture
      * @see endPointerSwipeGesture
-     * @since 5.29
-     **/
+     */
     void cancelPointerSwipeGesture();
 
     /**
@@ -504,8 +479,7 @@ public:
      * @see endPointerPinchGesture
      * @see cancelPointerPinchGesture
      * @see startPointerSwipeGesture
-     * @since 5.29
-     **/
+     */
     void startPointerPinchGesture(quint32 fingerCount);
 
     /**
@@ -518,8 +492,7 @@ public:
      * @see startPointerPinchGesture
      * @see endPointerPinchGesture
      * @see cancelPointerPinchGesture
-     * @since 5.29
-     **/
+     */
     void updatePointerPinchGesture(const QSizeF &delta, qreal scale, qreal rotation);
 
     /**
@@ -527,8 +500,7 @@ public:
      * @see startPointerPinchGesture
      * @see updatePointerPinchGesture
      * @see cancelPointerPinchGesture
-     * @since 5.29
-     **/
+     */
     void endPointerPinchGesture();
 
     /**
@@ -536,76 +508,10 @@ public:
      * @see startPointerPinchGesture
      * @see updatePointerPinchGesture
      * @see endPointerPinchGesture
-     * @since 5.29
-     **/
+     */
     void cancelPointerPinchGesture();
     ///@}
 
-    /**
-     * @name keyboard related methods
-     **/
-    ///@{
-#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 69)
-    /**
-     * @deprecated since 5.69, use setKeymapData
-     **/
-    KWAYLANDSERVER_DEPRECATED_VERSION(5, 69, "Use SeatInterface::setKeymapData()")
-    void setKeymap(int fd, quint32 size);
-#endif
-    /**
-     * Sets the xkb keymap with @p content for this Seat.
-     * The content gets sent to all registered KeyboardInterfaces
-     * @since 5.69
-     **/
-    void setKeymapData(const QByteArray &content);
-    void keyPressed(quint32 key);
-    void keyReleased(quint32 key);
-    void updateKeyboardModifiers(quint32 depressed, quint32 latched, quint32 locked, quint32 group);
-    /**
-     * Sets the key repeat information to be forwarded to all bound keyboards.
-     *
-     * To disable key repeat set a @p charactersPerSecond of @c 0.
-     *
-     * Requires wl_seat version 4.
-     *
-     * @param charactersPerSecond The characters per second rate, value of @c 0 disables key repeating
-     * @param delay The delay on key press before starting repeating keys
-     *
-     * @since 5.5
-     ***/
-    void setKeyRepeatInfo(qint32 charactersPerSecond, qint32 delay);
-    quint32 depressedModifiers() const;
-    quint32 latchedModifiers() const;
-    quint32 lockedModifiers() const;
-    quint32 groupModifiers() const;
-    quint32 lastModifiersSerial() const;
-#if KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(5, 69)
-    /**
-     * @deprecated since 5.69
-     **/
-    int KWAYLANDSERVER_DEPRECATED keymapFileDescriptor() const;
-    /**
-     * @deprecated since 5.69
-     **/
-    quint32 KWAYLANDSERVER_DEPRECATED keymapSize() const;
-#endif
-    bool isKeymapXkbCompatible() const;
-    QVector<quint32> pressedKeys() const;
-    /**
-     * @returns The key repeat in character per second
-     * @since 5.5
-     * @see setKeyRepeatInfo
-     * @see keyRepeatDelay
-     **/
-    qint32 keyRepeatRate() const;
-    /**
-     * @returns The delay on key press before starting repeating keys
-     * @since 5.5
-     * @see keyRepeatRate
-     * @see setKeyRepeatInfo
-     **/
-    qint32 keyRepeatDelay() const;
-
     /**
      * Passes keyboard focus to @p surface.
      *
@@ -615,38 +521,39 @@ public:
      * @see focusedKeyboardSurface
      * @see hasKeyboard
      * @see setFocusedTextInputSurface
-     **/
+     */
     void setFocusedKeyboardSurface(SurfaceInterface *surface);
     SurfaceInterface *focusedKeyboardSurface() const;
-    KeyboardInterface *focusedKeyboard() const;
+    KeyboardInterface *keyboard() const;
+    void notifyKeyboardKey(quint32 keyCode, KeyboardKeyState state);
+    void notifyKeyboardModifiers(quint32 depressed, quint32 latched, quint32 locked, quint32 group);
     ///@}
 
     /**
      * @name  touch related methods
-     **/
+     */
     ///@{
     void setFocusedTouchSurface(SurfaceInterface *surface, const QPointF &surfacePosition = QPointF());
     SurfaceInterface *focusedTouchSurface() const;
-    TouchInterface *focusedTouch() const;
+    TouchInterface *touch() const;
     void setFocusedTouchSurfacePosition(const QPointF &surfacePosition);
     QPointF focusedTouchSurfacePosition() const;
-    qint32 touchDown(const QPointF &globalPosition);
-    void touchUp(qint32 id);
-    void touchMove(qint32 id, const QPointF &globalPosition);
-    void touchFrame();
-    void cancelTouchSequence();
+    void notifyTouchDown(qint32 id, const QPointF &globalPosition);
+    void notifyTouchUp(qint32 id);
+    void notifyTouchMotion(qint32 id, const QPointF &globalPosition);
+    void notifyTouchFrame();
+    void notifyTouchCancel();
     bool isTouchSequence() const;
     /**
      * @returns true if there is a touch sequence going on associated with a touch
      * down of the given @p serial.
-     * @since 5.XX
-     **/
+     */
     bool hasImplicitTouchGrab(quint32 serial) const;
     ///@}
 
     /**
      * @name Text input related methods.
-     **/
+     */
     ///@{
     /**
      * Passes text input focus to @p surface.
@@ -654,24 +561,22 @@ public:
      * If the SeatInterface has the keyboard capability this method will
      * be invoked automatically when setting the focused keyboard surface.
      *
-     * In case there is a TextInputInterface for the @p surface, the enter
-     * event will be triggered on the TextInputInterface for @p surface.
-     * The focusedTextInput will be set to that TextInputInterface. If there
-     * is no TextInputInterface for that @p surface, it might get updated later on.
+     * In case there is a TextInputV2Interface for the @p surface, the enter
+     * event will be triggered on the TextInputV2Interface for @p surface.
+     * The focusedTextInput will be set to that TextInputV2Interface. If there
+     * is no TextInputV2Interface for that @p surface, it might get updated later on.
      * In both cases the signal focusedTextInputChanged will be emitted.
      *
      * @see focusedTextInputSurface
      * @see focusedTextInput
      * @see focusedTextInputChanged
      * @see setFocusedKeyboardSurface
-     * @since 5.23
-     **/
+     */
     void setFocusedTextInputSurface(SurfaceInterface *surface);
     /**
      * @returns The SurfaceInterface which is currently focused for text input.
      * @see setFocusedTextInputSurface
-     * @since 5.23
-     **/
+     */
     SurfaceInterface *focusedTextInputSurface() const;
     /**
      * The currently focused text input, may be @c null even if there is a
@@ -679,22 +584,22 @@ public:
      *
      * The focused text input might not be enabled for the {@link focusedTextInputSurface}.
      * It is recommended to check the enabled state before interacting with the
-     * TextInputInterface.
+     * TextInputV2Interface.
      *
      * @see focusedTextInputChanged
      * @see focusedTextInputSurface
-     * @since 5.23
-     **/
-    TextInputInterface *focusedTextInput() const;
+     */
+    TextInputV2Interface *textInputV2() const;
+    
+    TextInputV3Interface *textInputV3() const;
     ///@}
 
     /**
      * @returns The DataDeviceInterface holding the current clipboard selection.
-     * @since 5.24
      * @see selectionChanged
      * @see setSelection
      * This may be null
-     **/
+     */
     KWaylandServer::AbstractDataSource *selection() const;
 
     /**
@@ -708,8 +613,7 @@ public:
      * @param dataDevice Sets the current clipboard selection.
      * @see selection
      * @see selectionChanged
-     * @since 5.24
-     **/
+     */
     void setSelection(AbstractDataSource *selection);
 
     void setPrimarySelection(AbstractDataSource *selection);
@@ -725,70 +629,45 @@ Q_SIGNALS:
     void touchMoved(qint32 id, quint32 serial, const QPointF &globalPosition);
     void timestampChanged(quint32);
 
-    void pointerCreated(KWaylandServer::PointerInterface*);
-    void keyboardCreated(KWaylandServer::KeyboardInterface*);
-    void touchCreated(KWaylandServer::TouchInterface*);
-
-    /**
-     * Emitted whenever the focused pointer changes
-     * @since 5.6
-     **/
-    void focusedPointerChanged(KWaylandServer::PointerInterface*);
-
     /**
      * Emitted whenever the selection changes
-     * @since 5.56
      * @see selection
      * @see setSelection
-     **/
+     */
     void selectionChanged(KWaylandServer::AbstractDataSource*);
 
     /**
      * Emitted whenever the primary selection changes
      * @see primarySelection
-     **/
+     */
     void primarySelectionChanged(KWaylandServer::AbstractDataSource*);
 
     /**
      * Emitted when a drag'n'drop operation is started
-     * @since 5.6
      * @see dragEnded
-     **/
+     */
     void dragStarted();
     /**
      * Emitted when a drag'n'drop operation ended, either by dropping or canceling.
-     * @since 5.6
      * @see dragStarted
-     **/
+     */
     void dragEnded();
     /**
      * Emitted whenever the drag surface for motion events changed.
-     * @since 5.6
      * @see dragSurface
-     **/
+     */
     void dragSurfaceChanged();
     /**
      * Emitted whenever the focused text input changed.
      * @see focusedTextInput
-     * @since 5.23
-     **/
-    void focusedTextInputChanged();
+     */
+    void focusedTextInputSurfaceChanged();
 
 private:
-    friend class Display;
-    friend class DataControlDeviceV1Interface;
-    friend class PrimarySelectionDeviceV1Interface;
-    friend class DataDeviceManagerInterface;
-    friend class TextInputManagerUnstableV0Interface;
-    friend class TextInputManagerUnstableV2Interface;
-    explicit SeatInterface(Display *display, QObject *parent);
-
-    class Private;
-    Private *d_func() const;
+    QScopedPointer<SeatInterfacePrivate> d;
+    friend class SeatInterfacePrivate;
 };
 
 }
 
 Q_DECLARE_METATYPE(KWaylandServer::SeatInterface*)
-
-#endif
